cva.aglm()Class for results of cva.aglm()
models_listA list consists of cv.glmnet()'s results for all \(\alpha\) values.
alphaSame as in cv.aglm.
nfoldsSame as in cv.aglm.
alpha.min.indexThe index of alpha.min in the vector alpha.
alpha.minThe \(\alpha\) value achieving the minimum loss among all the values of alpha.
lambda.minThe \(\lambda\) value achieving the minimum loss when \(\alpha\) is equal to alpha.min.
callAn object of class call, corresponding to the function call when this CVA_AccurateGLM object is created.
Kenji Kondo