Get coefficients
# S3 method for AccurateGLM
coef(object, index = NULL, name = NULL, s = NULL, exact = FALSE, ...)If index or name is given, the function returns a list with the one or combination
of the following fields, consisting of coefficients related to the specified variable.
coef.linear: A coefficient of the linear term. (If any)
coef.OD: Coefficients of O-dummies. (If any)
coef.UD: Coefficients of U-dummies. (If any)
coef.LV: Coefficients of L-variables. (If any)
If both index and name are not given, the function returns entire coefficients
corresponding to the internal designed matrix.
A model object obtained from aglm() or cv.aglm().
An integer value representing the index of variable whose coefficients are required.
A string representing the name of variable whose coefficients are required.
Note that if both index and name are set, index is discarded.
Same as in coef.glmnet.
Same as in coef.glmnet.
Other arguments are passed directly to coef.glmnet().
Kenji Kondo